# vim: set ts=4 sw=4 et: coding=UTF-8

from .rpmsection import Section


class RpmFiles(Section):

    """
        Class that does replacements on the %files section.
    """

    def add(self, line):
        line = self._complete_cleanup(line)
        line = self.strip_useless_spaces(line)

        if not self.minimal:
            self._add_defattr(line)

        # toss out empty lines if there are more than one in succession
        if line == '' and (not self.previous_line or self.previous_line == ''):
            return

        line = self._remove_doc_on_man(line)

        Section.add(self, line)

    def _add_defattr(self, line):
        """
        Add defattr with default values if there is none
        """
        # if it is 2nd line and it is not defattr just set there some default
        if self.previous_line and \
                self.reg.re_spec_files.match(self.previous_line) and \
                not line.startswith('%defattr'):
            self.lines.append('%defattr(-,root,root)')

    def _remove_doc_on_man(self, line):
        """
        Remove all %doc %_mandir to -> %_mandir as it is pointless to do twice
        """
        line = line.replace("%doc %{_mandir}", "%{_mandir}", 1)
        line = line.replace("%doc %{_infodir}", "%{_infodir}", 1)
        return line



# vim: set ts=4 sw=4 et: coding=UTF-8

import os

from .rpmexception import RpmException


class FileUtils(object):

    """
    Class working with file operations.
    Read/write..
    """

    # file variable
    f = None

    def open_datafile(self, FILE):
        """
        Function to open data files.
        Used all around so kept glob here for importing.
        """

        try:
            f = open('{0}/../data/{1}'.format(os.path.dirname(os.path.realpath(__file__)), FILE), 'r')
        except IOError:
            # the .. is appended as we are in spec_cleaner sub_folder
            try:
                f = open('/usr/share/spec-cleaner/{0}'.format(FILE), 'r')
            except IOError as e:
                raise RpmException(e)

        self.f = f

    def open(self, FILE, mode):
        """
        Function to open regular files with exception handling.
        """

        try:
            f = open(FILE, mode)
        except IOError as error:
            raise RpmException(error)

        self.f = f

    def close(self):
        """
        Just wrapper for closing the file
        """

        if self.f:
            self.f.close()

    def __del__(self):
        self.close()
        self.f = None



# vim: set ts=4 sw=4 et: coding=UTF-8

from .rpmsection import Section


class RpmScriptlets(Section):

    '''
        Do %post -p /sbin/ldconfig when only scriplet command is /sbin/ldconfig
    '''

    def output(self, fout, newline=True, new_class=None):
        if not self.minimal:
            self._collapse_multiline_ldconfig(newline)
        Section.output(self, fout, newline, new_class)

    def _collapse_multiline_ldconfig(self, newline):
        nolines = len(self.lines)
        # if we have 2 or 3 lines where last one is empty
        if nolines == 2 or (nolines == 3 and self.lines[2] == ''):
            if self.lines[0] != '' and self.lines[1] == '':
                self.lines.pop()
            if len(self.lines) >= 2:
                if self.lines[1] == '/sbin/ldconfig':
                    pkg = self.lines[0]
                    self.lines = []
                    self.lines.append('{0} -p /sbin/ldconfig'.format(pkg))
